﻿using System;
using System.Threading;

namespace KbdLedC
{
    ////////////////////////////////////////////////////////////////////////////////
    // Switching Keyboard LEDs by toggling NumLock, CapsLock and ScrollLock
    // Console Application for using KbdLEDs library in Batch
    // © 2014 JoAchim Berg, Hamburg, Germany, achim_berg_de@yahoo.com
    ////////////////////////////////////////////////////////////////////////////////

    class Program
    {
        private static bool waitingForTermination = true;

        static void Main(string[] args)
        {
            bool hasErrors = args.Length < 1;
            int intervalPending = 0;

            foreach (string t in args)
            {
                if (!oneParam(t, ref intervalPending)) hasErrors = true;
            }

            // any impulses pending? then wait
            if (intervalPending > 0)
            {
                Timer t = new Timer(onTimer, null, intervalPending + 500, 500);

                while (waitingForTermination)
                {
                    Thread.Sleep(100);
                }
            }

            if (hasErrors) ShowSyntax();
        }

        private static void onTimer(object state)
        {
            waitingForTermination = false;
        }

        private static bool oneParam(string s, ref int interval)
        {
            if (!s.StartsWith("/") || (s.Length < 4)) return false;
            
            // get LED
            KbdLEDs.LED led;
            char cLed = s[1];
            switch (char.ToLower(cLed))
            {
                case 's': led = KbdLEDs.LED.ScrollLock; break;
                case 'n': led = KbdLEDs.LED.NumLock; break;
                case 'c': led = KbdLEDs.LED.CapsLock; break;
                default: return false;
            }

            // get state/duration cmd
            s = s[2] == '='
                ? s = s.Substring(3)  //  /L=x
                : s = s.Substring(2); //  /Lx

            int cmd;
            if (!int.TryParse(s, out cmd)) return false;

            if (cmd <= 1) // 0 or 1
            {
                KbdLEDs.LEDs.SetToggleState(led, cmd == 1);
            }
            else // impulse length in ms
            {
                KbdLEDs.LEDs.Impulse(led, cmd);
                if (cmd > interval) interval = cmd; // remember impulse is pending
            }
            return true;
        }

        static void ShowSyntax()
        {
            Console.WriteLine("parameters may be /c (CapsLock), /n (NumLock), /s (Scrolllock)");
            Console.WriteLine("Examples: /c=0 /c=1 /n=0 /n=1 s=0 /s=1");
            Console.WriteLine("Numbers > 1 are impulse lengths in msec");
            Console.WriteLine("Examples: /n=1000 /s=200");
            Console.ReadKey();
        }
    }
}
